@@ -103,15 +103,19 @@ class ModelParser:
 
 
 def replace_dots_for_tf_ops_inbound_nodes(layer, dot_input_names):
-    inbound_nodes_to_enumerate = KerasJsonModelImport.prepare_inbound_nodes_of_tf_ops(layer['inbound_nodes'][0])
+    inbound_nodes_to_enumerate = KerasJsonModelImport.prepare_inbound_nodes(layer['inbound_nodes'][0])
     if len(inbound_nodes_to_enumerate) == 1:
         if layer['inbound_nodes'][0][0] in dot_input_names:
             layer['inbound_nodes'][0][0] = layer['inbound_nodes'][0][0].replace(".", "_")
     elif len(inbound_nodes_to_enumerate) == 2:
         if layer['inbound_nodes'][0][0] in dot_input_names:
             layer['inbound_nodes'][0][0] = layer['inbound_nodes'][0][0].replace(".", "_")
-        if layer['inbound_nodes'][0][-1]['y'][0] in dot_input_names:
-            layer['inbound_nodes'][0][0] = layer['inbound_nodes'][0][0].replace(".", "_")
+        try:
+            if layer['inbound_nodes'][0][-1]['y'][0] in dot_input_names:
+                layer['inbound_nodes'][0][0] = layer['inbound_nodes'][0][0].replace(".", "_")
+        except KeyError:
+            if layer['inbound_nodes'][0][-1]['b'][0] in dot_input_names:
+                layer['inbound_nodes'][0][0] = layer['inbound_nodes'][0][0].replace(".", "_")
     else:
         raise Exception('unsupported inbound_nodes')
 
